package com.logicbig.example;

import javax.validation.*;
import java.util.Comparator;
import java.util.Set;

public class ExampleMain {
    public static void main(String[] args) {
        Validator validator = createValidator();
        Employee employee = new EmployeeImpl("",
                new PhoneNumber("cell", "234-3334"), null);
        Set<ConstraintViolation<Employee>> violations = validator.validate(employee);
        violations.stream().sorted(Comparator.comparing(o -> o.getPropertyPath().toString()))
                .forEach(ExampleMain::printError);
    }

    private static void printError(ConstraintViolation<?> violation) {
        System.out.println(violation.getPropertyPath()
                + " " + violation.getMessage());
    }

    private static Validator createValidator() {
        Configuration<?> config = Validation.byDefaultProvider().configure();
        ValidatorFactory factory = config.buildValidatorFactory();
        Validator validator = factory.getValidator();
        factory.close();
        return validator;
    }
}